// AlphaDoc.h
// (c) 2003-2005 exeal

#ifndef _ALPHA_DOC_H_
#define _ALPHA_DOC_H_

#include "Ascension\EditDoc.h"
#include "AmbientIdl.h"


namespace Alpha {
	class CAlphaApp;
	class CAlphaView;
	namespace Ambient {
		class CBuffer;
	}
/*
	///	u[N|Cg̏
	enum BreakPointState {
		BPS_NONE,	///< ݒ肳ĂȂ
		BPS_ENABLE,	///< Lu[N|Cg
		BPS_DISABLE	///< u[N|Cg
	};


	// CAlphaDocLine class definition
	/////////////////////////////////////////////////////////////////////////////

	class CAlphaDocLine : public CEditDocLine {
		// f[^o
	private:
		BreakPointState	m_bps;

		// \bh
	public:
		BreakPointState	GetBreakPointState() const {
			return m_bps;
		}
	};
*/

	class CAlphaDoc : public Ascension::CEditDoc {
		// RXgN^
	public:
		CAlphaDoc();
		virtual ~CAlphaDoc();

		// \bh
	public:
		CAlphaView&		GetActiveView() const throw(std::logic_error);
		HRESULT			GetAutomation(CAlphaApp& app, IBuffer** ppBuffer) const;
		const TCHAR*	GetFileName() const;
		CAlphaView&		GetView(std::size_t iView) const throw(std::out_of_range);

		// f[^o
	protected:
		Ambient::CBuffer*	m_pAutomation;	// I[g[VpC^[tFCX
	public:
		std::wstring	m_strDocType;	// KpĂ镶^Cv
	};
}

#endif /* _ALPHA_EDIT_H_ */

/* [EOF] */